@@ -195,6 +195,112 @@ conjugacyRelationshipsClass <- setRefClass(
             names(conjugacys) <<- unlist(lapply(conjugacys, function(cr) cr$prior))
         },
         checkConjugacy = function(model, nodeIDs, restrictLink = NULL) {
+            if(isTRUE(getNimbleOption("oldConjugacyChecking")))
+                checkConjugacy_original(model, nodeIDs, restrictLink)
+            else
+                checkConjugacy_new(model, nodeIDs, restrictLink)
+        },
+        checkConjugacy_new = function(model, nodeIDs, restrictLink = NULL) {
+            maps <- model$modelDef$maps
+            nodeDeclIDs <- maps$graphID_2_declID[nodeIDs] ## declaration IDs of the nodeIDs
+            declID2nodeIDs <- split(nodeIDs, nodeDeclIDs) ## nodeIDs grouped by declarationID
+            ansList <- ansList2 <- list()
+            for(i in seq_along(declID2nodeIDs)) {         ## For each group of nodeIDs from the same declarationID
+                nodeIDsFromOneDecl <- declID2nodeIDs[[i]]
+                firstNodeName <- maps$graphID_2_nodeName[nodeIDsFromOneDecl[1]]
+                if(model$isTruncated(firstNodeName)) next   ## we say non-conjugate if the targetNode is truncated
+                dist <- model$getDistribution(firstNodeName)
+                conjugacyObj <- conjugacys[[dist]]
+                if(is.null(conjugacyObj)) next
+                # NO: insert logic here to check a single dependency and do next if can't be conjugate
+                #model$getDependencies('mu[1]',self=F,stochOnly=T)
+                #for( loop through deps )
+                #    conjugacyObj$checkConjugacyOneDep(model, targetNode, depNode)
+                #    if(not conj) next
+
+                # now try to guess if finding paths will be more intensive than simply looking at target-dependent pairs, to avoid path finding when there is nested structure such as stickbreaking
+                numPaths <- sapply(nodeIDsFromOneDecl, model$getDependencyPathCountOneNode)
+                deps <- lapply(nodeIDsFromOneDecl, function(x) model$getDependencies(x, stochOnly = TRUE, self = FALSE))
+                numDeps <- sapply(deps, length)
+
+                if(max(numPaths) > sum(numDeps)) {
+                    # max(numPaths) is reasonable guess at number of unique (by node) paths (though it overestimates number of unique (by declaration ID) paths; if we have to evaluate conjugacy for more paths than we would by simply looking at all pairs of target-dependent nodes, then just use node pairs
+                    # note that it's not clear what criterion to use here since computational time is combination of time for finding all paths and then for evaluating conjugacy for unique (by declaration ID) paths, but the hope is to make a crude cut here that avoids path calculations when there would be a lot of them
+                    ansList[[length(ansList)+1]] <- lapply(seq_along(nodeIDsFromOneDecl),
+                        function(index) {
+                            targetNode <- maps$graphID_2_nodeName[nodeIDsFromOneDecl[index]]
+                            depEnds <- deps[[index]]
+                            depTypes <- sapply(depEnds, function(x) conjugacyObj$checkConjugacyOneDep(model, targetNode, x, restrictLink))
+                            if(!length(depTypes)) return(NULL)
+                            if(!any(sapply(depTypes, is.null))) {
+                                uniqueDepTypes <- unique(depTypes)
+                                control <- lapply(uniqueDepTypes,
+                                                  function(oneType) {
+                                                      boolMatch <- depTypes == oneType
+                                                      depEnds[boolMatch]
+                                                  })
+                                names(control) <- uniqueDepTypes
+                                return(list(prior = conjugacyObj$prior, type = conjugacyObj$samplerType, target = targetNode, control = control))
+                            } else return(NULL)
+                        })
+                    names(ansList[[length(ansList)]]) <- maps$graphID_2_nodeName[nodeIDsFromOneDecl]
+                    
+                } else {
+                # determine conjugacy based on unique (by declaration ID) paths
+                    depPathsByNode <- lapply(nodeIDsFromOneDecl, model$getDependencyPaths)  ## make list (by nodeID) of lists of paths through graph
+                    depPathsByNode <- depPathsByNode[!unlist(lapply(depPathsByNode, function(x) is.null(x) || (length(x)==0)))]
+                    depPathsByNodeLabels <- lapply(depPathsByNode, function(z)                     ## make character labels that match for same path through graph
+                        unlist(lapply(z,
+                                      function(x)
+                                          paste(maps$graphID_2_declID[x[,1]], x[,2], collapse = '\r', sep='\r'))))
+                    
+                    depPathsByNodeUnlisted <- unlist(depPathsByNode, recursive = FALSE)
+                    depPathsByNodeLabelsUnlisted <- unlist(depPathsByNodeLabels)
+                    ##  uniquePaths <- unique(depPathsByNodeLabelsUnlisted)
+                    uniquePathsUnlistedIndices <- split(seq_along(depPathsByNodeLabelsUnlisted), depPathsByNodeLabelsUnlisted)
+                    
+                    conjDepTypes <- character(length(uniquePathsUnlistedIndices))
+                    for(j in seq_along(uniquePathsUnlistedIndices)) {
+                        firstDepPath <- depPathsByNodeUnlisted[[ uniquePathsUnlistedIndices[[j]][1] ]]
+                        targetNode <- maps$graphID_2_nodeName[firstDepPath[1,1]]
+                        depNode <- maps$graphID_2_nodeName[firstDepPath[nrow(firstDepPath), 1]]
+                        oneDepType <- conjugacyObj$checkConjugacyOneDep(model, targetNode, depNode, restrictLink)
+                        conjDepTypes[j] <- if(is.null(oneDepType)) "" else oneDepType
+                    }
+                    
+                    conjBool <- conjDepTypes != ""
+                    names(conjDepTypes) <- names(conjBool) <- names(uniquePathsUnlistedIndices)
+                    if(any(conjBool)) {
+                        targetNodes <- unlist(lapply(depPathsByNode, function(x) if(is.null(x)) '_NO_DEPS_' else maps$graphID_2_nodeName[x[[1]][1,1]]))
+                        ansList[[length(ansList)+1]] <- mapply(
+                            function(targetNode, depPathsOneNode, depPathsLabelsOneNode) {
+                                if(targetNode == '_NO_DEPS_') return(NULL) ## these should have already been weeded out
+                                if(all(conjBool[depPathsLabelsOneNode])) {
+                                    depTypes <- conjDepTypes[depPathsLabelsOneNode]
+                                    depEnds <- maps$graphID_2_nodeName[ unlist(lapply(depPathsOneNode, function(x) x[nrow(x)])) ]
+                                    uniqueDepTypes <- unique(depTypes)
+                                    control <- lapply(uniqueDepTypes,
+                                                      function(oneType) {
+                                                          boolMatch <- depTypes == oneType
+                                                          ## prevent multiple instances of same dependent node name
+                                                          ## (via different graph dependency paths   -DT Oct 2016
+                                                          ##depEnds[boolMatch]
+                                                          unique(depEnds[boolMatch])
+                                                      })
+                                    names(control) <- uniqueDepTypes
+                                    list(prior = conjugacyObj$prior, type = conjugacyObj$samplerType, target = targetNode, control = control)
+                                }
+                            },
+                            targetNodes, depPathsByNode, depPathsByNodeLabels, USE.NAMES = TRUE, SIMPLIFY = FALSE)
+                    }
+                }
+            }
+            if(length(ansList) > 0) ansList <- do.call('c', ansList)
+            ansList <- ansList[!sapply(ansList, is.null)]  # strips out any NULL values
+            if(!length(ansList)) return(list()) else return(ansList)  # replaces empty named list with empty list
+        },
+
+        checkConjugacy_original = function(model, nodeIDs, restrictLink = NULL) {
             maps <- model$modelDef$maps
             nodeDeclIDs <- maps$graphID_2_declID[nodeIDs] ## declaration IDs of the nodeIDs
             declID2nodeIDs <- split(nodeIDs, nodeDeclIDs) ## nodeIDs grouped by declarationID
@@ -358,13 +464,15 @@ conjugacyClass <- setRefClass(
                 if(!is.null(dependentObj$link)) currentLink <- dependentObj$link else currentLink <- link # handle multiple link case introduced for beta stickbreaking
             } else currentLink = restrictLink
             if(currentLink != 'stick_breaking') {
-                linearityCheckExpr <- model$getParamExpr(depNode, dependentObj$param)   # extracts the expression for 'param' from 'depNode'
-                linearityCheckExpr <- cc_expandDetermNodesInExpr(model, linearityCheckExpr, targetNode = targetNode)
+                depNodeParamName <- dependentObj$param
+                linearityCheckExprRaw <- model$getParamExpr(depNode, depNodeParamName)   # extracts the expression for 'param' from 'depNode'
+                linearityCheckExpr <- cc_expandDetermNodesInExpr(model, linearityCheckExprRaw, targetNode = targetNode)
                 if(!cc_nodeInExpr(targetNode, linearityCheckExpr))                return(NULL)
                 if(cc_vectorizedComponentCheck(targetNode, linearityCheckExpr))   return(NULL)   # if targetNode is vectorized, make sure none of its components appear in expr
                 linearityCheck <- cc_checkLinearity(linearityCheckExpr, targetNode)   # determines whether paramExpr is linear in targetNode
-                if(!cc_linkCheck(linearityCheck, currentLink))                           return(NULL)
-                if(!cc_otherParamsCheck(model, depNode, targetNode))              return(NULL)   # ensure targetNode appears in only *one* depNode parameter expression
+                if(!cc_linkCheck(linearityCheck, currentLink))   return(NULL)
+                ## ensure targetNode appears in only *one* depNode parameter expression
+                if(!cc_otherParamsCheck(model, depNode, targetNode, depNodeExprExpanded = linearityCheckExpr, depParamNodeName = depNodeParamName))   return(NULL)
             } else {
                 stickbreakingCheckExpr <- model$getParamExpr(depNode, dependentObj$param)   # extracts the expression for 'param' from 'depNode'
                 stickbreakingCheckExpr <- cc_expandDetermNodesInExpr(model, stickbreakingCheckExpr, targetNode = targetNode)
@@ -943,7 +1051,7 @@ cc_makeRDistributionName     <- function(distName)     return(paste0('r', substr
 
 
 ## expands all deterministic nodes in expr, to create a single expression with only stochastic nodes
-cc_expandDetermNodesInExpr <- function(model, expr, targetNode = NULL, skipExpansions=FALSE) {
+cc_expandDetermNodesInExpr <- function(model, expr, targetNode = NULL, skipExpansionsNode = NULL) {
     if(is.numeric(expr)) return(expr)     # return numeric
     if(is.name(expr) || (is.call(expr) && (expr[[1]] == '[') && is.name(expr[[2]]))) { # expr is a name, or an indexed name
         if(nimbleOptions()$allowDynamicIndexing) {
@@ -964,7 +1072,7 @@ cc_expandDetermNodesInExpr <- function(model, expr, targetNode = NULL, skipExpan
                         ## now check that target is not actually used in index expressions
                         newExpr <- as.call(c(cc_structureExprName, sapply(indexExprs[!numericOrVectorIndices], function(x) x)))
                         for(i in seq_along(newExpr)[-1])
-                            newExpr[[i]] <- cc_expandDetermNodesInExpr(model, newExpr[[i]], targetNode, skipExpansions)
+                            newExpr[[i]] <- cc_expandDetermNodesInExpr(model, newExpr[[i]], targetNode, skipExpansionsNode)
                         if(cc_nodeInExpr(targetNode, newExpr))
                             return(as.call(c(cc_structureExprName, expr, sapply(indexExprs[!numericOrVectorIndices], function(x) x))))  # put 'expr' back in though shouldn't be needed downstream
                         ## otherwise continue with processing as in non-dynamic index case
@@ -976,7 +1084,7 @@ cc_expandDetermNodesInExpr <- function(model, expr, targetNode = NULL, skipExpan
                         ## sapply business gets rid of () at end of index expression
                         newExpr <- as.call(c(cc_structureExprName, expr, sapply(indexExprs[!numericOrVectorIndices], function(x) x)))
                         for(i in seq_along(newExpr)[-1])
-                            newExpr[[i]] <- cc_expandDetermNodesInExpr(model, newExpr[[i]], targetNode, skipExpansions)
+                            newExpr[[i]] <- cc_expandDetermNodesInExpr(model, newExpr[[i]], targetNode, skipExpansionsNode)
                         return(newExpr)
                     }
                 }  ## else continue with processing as in non-dynamic index case
@@ -984,37 +1092,39 @@ cc_expandDetermNodesInExpr <- function(model, expr, targetNode = NULL, skipExpan
         }
         exprText <- deparse(expr)
         expandedNodeNamesRaw <- model$expandNodeNames(exprText)
+        if(!is.null(skipExpansionsNode) && (exprText %in% model$expandNodeNames(skipExpansionsNode, returnScalarComponents=TRUE))) return(expr)
         ## if exprText is a node itself (and also part of a larger node), then we only want the expansion to be the exprText node:
-        expandedNodeNames <- if((exprText %in% expandedNodeNamesRaw) || skipExpansions) exprText else expandedNodeNamesRaw
+        expandedNodeNames <- if(exprText %in% expandedNodeNamesRaw) exprText else expandedNodeNamesRaw
         if(length(expandedNodeNames) == 1 && (expandedNodeNames == exprText)) {
             ## expr is a single node in the model
             type <- model$getNodeType(exprText)
             if(length(type) > 1) {
                 ## if exprText is a node itself (and also part of a larger node), then we only want the expansion to be the exprText node:
                 if(exprText %in% expandedNodeNamesRaw) type <- type[which(exprText == expandedNodeNamesRaw)]
-                else stop('something went wrong with Daniel\'s understanding of newNimbleModel')
+                else stop('something went wrong with Daniel\'s understanding of newNimbleModel #1')
             }
             if(type == 'stoch') return(expr)
             if(type == 'determ') {
                 newExpr <- model$getValueExpr(exprText)
-                return(cc_expandDetermNodesInExpr(model, newExpr, targetNode, skipExpansions))
+                return(cc_expandDetermNodesInExpr(model, newExpr, targetNode, skipExpansionsNode))
             }
             if(type == 'RHSonly') return(expr)
-            stop('something went wrong with Daniel\'s understanding of newNimbleModel')
+            stop('something went wrong with Daniel\'s understanding of newNimbleModel #2')
         }
         newExpr <- cc_createStructureExpr(model, exprText)
         for(i in seq_along(newExpr)[-1])
-            newExpr[[i]] <- cc_expandDetermNodesInExpr(model, newExpr[[i]], targetNode, skipExpansions)
+            newExpr[[i]] <- cc_expandDetermNodesInExpr(model, newExpr[[i]], targetNode, skipExpansionsNode)
         return(newExpr)
     }
     if(is.call(expr)) {
         for(i in seq_along(expr)[-1])
-            expr[[i]] <- cc_expandDetermNodesInExpr(model, expr[[i]], targetNode, skipExpansions)
+            expr[[i]] <- cc_expandDetermNodesInExpr(model, expr[[i]], targetNode, skipExpansionsNode)
         return(expr)
     }
     stop(paste0('something went wrong processing: ', deparse(expr)))
 }
 
+
 ## special name used to represent vectors / arrays defined in terms of other stoch/determ nodes
 cc_structureExprName <- quote(structureExpr)
 
@@ -1043,11 +1153,13 @@ cc_linkCheck <- function(linearityCheck, link) {
 
 ## checks the parameter expressions in the stochastic distribution of depNode
 ## returns FALSE if we find 'targetNode' in ***more than one*** of these expressions
-cc_otherParamsCheck <- function(model, depNode, targetNode, skipExpansions=FALSE) {
+cc_otherParamsCheck <- function(model, depNode, targetNode, skipExpansionsNode = NULL, depNodeExprExpanded, depParamNodeName) {
     paramsList <- as.list(model$getValueExpr(depNode)[-1])       # extracts the list of all parameters, for the distribution of depNode
     timesFound <- 0   ## for success, we'll find targetNode in only *one* parameter expression
     for(i in seq_along(paramsList)) {
-        expr <- cc_expandDetermNodesInExpr(model, paramsList[[i]], targetNode, skipExpansions)
+        if(!missing(depParamNodeName) && (names(paramsList)[i] == depParamNodeName)) {
+            expr <- depNodeExprExpanded
+        } else { expr <- cc_expandDetermNodesInExpr(model, paramsList[[i]], targetNode, skipExpansionsNode) }
         if(cc_vectorizedComponentCheck(targetNode, expr))   return(FALSE)
         if(cc_nodeInExpr(targetNode, expr))     { timesFound <- timesFound + 1 }    ## we found 'targetNode'
     }
@@ -1098,7 +1210,7 @@ cc_checkLinearity <- function(expr, targetNode) {
     if(identical(targetNode, deparse(expr)))
         return(list(offset = 0, scale = 1))
 
-    if(!is.call(expr))   stop('expression is not a call object')
+    if(!is.call(expr))   stop('cc_checkLinearity: expression is not a call object')
 
     ## process the expression contents of the parentheses
     if(expr[[1]] == '(')
@@ -1135,7 +1247,7 @@ cc_checkLinearity <- function(expr, targetNode) {
             return(list(offset = cc_negateExpr(checkLin$offset),
                         scale  = cc_negateExpr(checkLin$scale)))
         }
-        stop('problem with negation expression')
+        stop('cc_checkLinearity: problem with negation expression')
     }
 
     if(expr[[1]] == '+') {
@@ -1152,24 +1264,28 @@ cc_checkLinearity <- function(expr, targetNode) {
                                length(expr[[2]]) > 1 && expr[[2]][[1]] != 'structureExpr' &&
                                length(expr[[3]]) > 1 && expr[[3]][[1]] != 'structureExpr',
                                TRUE, FALSE)
-        if(expr[[1]] == 'sum' && length(expr[[2]]) == 3 && expr[[2]][[1]] == '*') {
-            tmpExpr <- quote(inprod(a, b))
-            tmpExpr[[2]] <- expr[[2]][[2]]
-            tmpExpr[[3]] <- expr[[2]][[3]]
-            expr <- tmpExpr
-        }
+        if(expr[[1]] == 'sum') 
+            if(length(expr[[2]]) == 3 && expr[[2]][[1]] == '*') {
+                tmpExpr <- quote(inprod(a, b))
+                tmpExpr[[2]] <- expr[[2]][[2]]
+                tmpExpr[[3]] <- expr[[2]][[3]]
+                expr <- tmpExpr
+            } else {
+                return(NULL)  # cases such as sum(p[1:5]); there may be some unusual conjugacy cases here that we don't detect
+            }
+        if(length(expr) != 3) return(NULL)  # avoid error at next step for unexpected cases
         if(cc_nodeInExpr(targetNode, expr[[2]]) && cc_nodeInExpr(targetNode, expr[[3]])) return(NULL)
         checkLinearityLHS <- cc_checkLinearity(expr[[2]], targetNode)
         checkLinearityRHS <- cc_checkLinearity(expr[[3]], targetNode)
         if(is.null(checkLinearityLHS) || is.null(checkLinearityRHS)) return(NULL)
-        if((checkLinearityLHS$scale != 0) && (checkLinearityRHS$scale != 0)) stop('incompatible scales in * operation')
+        if((checkLinearityLHS$scale != 0) && (checkLinearityRHS$scale != 0)) stop('cc_checkLinearity: incompatible scales in * operation')
         if(checkLinearityLHS$scale != 0) {
             return(list(offset = cc_combineExprsMultiplication(checkLinearityLHS$offset, checkLinearityRHS$offset, isMatrixMult),
                         scale  = cc_combineExprsMultiplication(checkLinearityLHS$scale,  checkLinearityRHS$offset, isMatrixMult))) }
         if(checkLinearityRHS$scale != 0) {
             return(list(offset = cc_combineExprsMultiplication(checkLinearityLHS$offset, checkLinearityRHS$offset, isMatrixMult),
                         scale  = cc_combineExprsMultiplication(checkLinearityLHS$offset, checkLinearityRHS$scale , isMatrixMult))) }
-        stop('something went wrong')
+        stop('cc_checkLinearity: something went wrong')
     }
 
     if(expr[[1]] == '/') {
