@@ -23,7 +23,7 @@
 #'
 #' @param setSeed Logical or numeric argument.  If a single numeric value is provided, R's random number seed will be set to this value at the onset of each MCMC chain.  If a numeric vector of length \code{nchains} is provided, then each element of this vector is provided as R's random number seed at the onset of the corresponding MCMC chain.  Otherwise, in the case of a logical value, if \code{TRUE}, then R's random number seed for the ith chain is set to be \code{i}, at the onset of each MCMC chain.  Note that specifying the argument \code{setSeed = 0} does not prevent setting the RNG seed, but rather sets the random number generation seed to \code{0} at the beginning of each MCMC chain.  Default value is \code{FALSE}.
 #'
-#' @param progressBar Logical argument.  If \code{TRUE}, an MCMC progress bar is displayed during execution of each MCMC chain.  Default value is \code{TRUE}.
+#' @param progressBar Logical argument.  If \code{TRUE}, an MCMC progress bar is displayed during execution of each MCMC chain.  Default value is defined by the nimble package option MCMCprogressBar.
 #'
 #' @param samples Logical argument.  If \code{TRUE}, then posterior samples are returned from each MCMC chain.  These samples are optionally returned as \code{coda} \code{mcmc} objects, depending on the \code{samplesAsCodaMCMC} argument.  Default value is \code{TRUE}.  See details.
 #'
@@ -90,7 +90,7 @@ runMCMC <- function(mcmc,
                     ## reinstate samplerExecutionOrder as a runtime argument, once we support non-scalar default values for runtime arguments:
                     ##samplerExecutionOrder,
                     setSeed = FALSE,
-                    progressBar = TRUE,
+                    progressBar = getNimbleOption('MCMCprogressBar'),
                     samples = TRUE,
                     samplesAsCodaMCMC = FALSE,
                     summary = FALSE,
@@ -150,8 +150,8 @@ runMCMC <- function(mcmc,
         WAICvalue <- mcmc$calculateWAIC()
     }
     if(samplesAsCodaMCMC) {
-        samplesList <- coda::as.mcmc.list(lapply(samplesList, as.mcmc))
-        if(hasMonitors2)   samplesList2 <- coda::as.mcmc.list(lapply(samplesList2, as.mcmc))
+        samplesList <- as.mcmc.list(lapply(samplesList, as.mcmc))
+        if(hasMonitors2)   samplesList2 <- as.mcmc.list(lapply(samplesList2, as.mcmc))
     }
     if(nchains == 1) {
         samplesList <- samplesList[[1]]                       ## returns matrix when nchains = 1
@@ -212,7 +212,7 @@ runMCMC <- function(mcmc,
 #' 
 #' @param setSeed Logical or numeric argument.  If a single numeric value is provided, R's random number seed will be set to this value at the onset of each MCMC chain.  If a numeric vector of length \code{nchains} is provided, then each element of this vector is provided as R's random number seed at the onset of the corresponding MCMC chain.  Otherwise, in the case of a logical value, if \code{TRUE}, then R's random number seed for the ith chain is set to be \code{i}, at the onset of each MCMC chain.  Note that specifying the argument \code{setSeed = 0} does not prevent setting the RNG seed, but rather sets the random number generation seed to \code{0} at the beginning of each MCMC chain.  Default value is \code{FALSE}.
 #'
-#' @param progressBar Logical argument.  If \code{TRUE}, an MCMC progress bar is displayed during execution of each MCMC chain.  Default value is \code{TRUE}.
+#' @param progressBar Logical argument.  If \code{TRUE}, an MCMC progress bar is displayed during execution of each MCMC chain.  Default value is defined by the nimble package option MCMCprogressBar..
 #'
 #' @param samples Logical argument.  If \code{TRUE}, then posterior samples are returned from each MCMC chain.  These samples are optionally returned as \code{coda} \code{mcmc} objects, depending on the \code{samplesAsCodaMCMC} argument.  Default value is \code{TRUE}.  See details.
 #'
@@ -277,7 +277,7 @@ nimbleMCMC <- function(code,
                        nchains = 1,
                        check = TRUE,
                        setSeed = FALSE,
-                       progressBar = TRUE,
+                       progressBar = getNimbleOption('MCMCprogressBar'),
                        samples = TRUE,
                        samplesAsCodaMCMC = FALSE,
                        summary = FALSE,
