@@ -19,8 +19,7 @@ RCfunctionDef <- setRefClass('RCfunctionDef',
                                                        '<math.h>',
                                                        nimbleIncludeFile("EigenTypedefs.h"),
                                                        nimbleIncludeFile("Utils.h"),
-                                                       nimbleIncludeFile("accessorClasses.h"),
-                                                       if(nimbleOptions('experimentalUseTensorflow')) nimbleIncludeFile("tensorflow.h") else character())
+                                                       nimbleIncludeFile("accessorClasses.h"))
                                      CPPusings <<- c(CPPusings) 
                                      callSuper(...)
                                  },
