@@ -25,7 +25,7 @@ nimbleListBase <- setRefClass(Class = 'nimbleListBase',
 
 #' create a nimbleType object
 #'
-#' create a nimbleType object, with information on the name, type, and dimension of an object to be placed in a \link{nimbleList} 
+#' Create a nimbleType object, with information on the name, type, and dimension of an object to be placed in a \code{\link{nimbleList}}.
 #'
 #' @param name The name of the object, given as a character string.
 #' @param type The type of the object, given as a character string.
@@ -37,10 +37,10 @@ nimbleListBase <- setRefClass(Class = 'nimbleListBase',
 #'
 #' @details
 #' 
-#' This function creates \code{nimbleType} objects, which can be used to define the elements of a \link{nimbleList}.  
+#' This function creates \code{nimbleType} objects, which can be used to define the elements of a \code{\link{nimbleList}}.  
 #' 
 #' The \code{type} argument can be chosen from among \code{character}, \code{double}, \code{integer}, and \code{logical},
-#' or can be the name of a previously created \link{nimbleList} definition.
+#' or can be the name of a previously created \code{\link{nimbleList} definition}.
 #' 
 #' See the NIMBLE User Manual for additional examples.
 #' 
@@ -81,7 +81,7 @@ nimbleType <- setRefClass(
 #'
 #' @details
 #' This function creates a definition for a nimbleList.  The \code{types} argument defines the names, types, and dimensions of the elements of the nimbleList.  Elements of nimbleLists can be either basic types (e.g., \code{integer}, \code{double}) or other nimbleList definitions.   
-#' The \code{types} argument can be either a series of expressions of the form \code{name = type(dim)}, or a list of \link{nimbleType} objects.
+#' The \code{types} argument can be either a series of expressions of the form \code{name = type(dim)}, or a list of \code{\link{nimbleType}} objects.
 #' 
 #' \code{nimbleList} returns a definition, which can be used to create instances of this type of nimbleList via the \code{new()} member function. 
 #' 
@@ -355,6 +355,23 @@ svdNimbleList <-  nimbleList(list(nimbleType('d', 'double', 1),
                                   nimbleType('u', 'double', 2),
                                   nimbleType('v', 'double', 2)), name = "EIGEN_SVDCLASS", predefined = TRUE)
 
+#' EXPERIMENTAL Data type for the return value of \code{\link{nimDerivs}}
+#'
+#' \code{\link{nimbleList}} definition for the type of \code{\link{nimbleList}} returned by \code{\link{nimDerivs}}.
+#'
+#' @field value The value of the function evaluated at the given input arguments. 
+#' @field gradient	The gradient of the function evaluated at the given input arguments. 
+#' @field hessian The Hessian of the function evaluated at the given input arguments. 
+#' @field thirdDerivs Currently unused.
+#'
+#' @export
+#' @seealso \code{\link{nimDerivs}}
+
+ADNimbleList <-  nimbleList(list(nimbleType('value', 'double', 1),
+                                 nimbleType('gradient', 'double', 2),
+                                 nimbleType('hessian', 'double', 3),
+                                 nimbleType('thirdDerivs', 'double', 4)),
+                            name = "NIMBLE_ADCLASS", predefined = TRUE)
 
 #' EXPERIMENTAL Data type for the return value of \code{\link{nimOptim}}
 #'
@@ -396,9 +413,10 @@ optimResultNimbleList <- nimbleList(
 optimControlNimbleList <- nimbleList(
     list(
         nimbleType('trace', 'integer', 0),
+        nimbleType('fnscale', 'double', 0),
         nimbleType('parscale', 'double', 1),
         nimbleType('ndeps', 'double', 1),
-        nimbleType('maxIt', 'integer', 0),
+        nimbleType('maxit', 'integer', 0),
         nimbleType('abstol', 'double', 0),
         nimbleType('reltol', 'double', 0),
         nimbleType('alpha', 'double', 0),
@@ -420,6 +438,8 @@ optimControlNimbleList <- nimbleList(
 ## functionName = list(nlGen = nimbleList definition, cppName = name of cpp function corresponding to dsl function)
 nimbleListReturningFunctionList <- list(nimEigen = list(nlGen = eigenNimbleList, cppName = 'EIGEN_EIGEN'),
                                         nimSvd = list(nlGen = svdNimbleList, cppName = "EIGEN_SVD"),
+                                        nimDerivs = list(nlGen = ADNimbleList, cppName = "NIM_DERIVS"),
+                                        getDerivs = list(nlGen = ADNimbleList, cppName = 'getDerivs'),
                                         nimOptim = list(nlGen = optimResultNimbleList, cppName = "OptimResultNimbleList"),
                                         nimOptimDefaultControl = list(nlGen = optimControlNimbleList, cppName = "OptimControlNimbleList"))
 
