@@ -1387,6 +1387,7 @@ MAKE_RECYCLING_RULE_CLASS3_1scalar(dgamma, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dinvgamma, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(ddexp, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dlnorm, double)
+MAKE_RECYCLING_RULE_CLASS3_1scalar(dlogis, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dunif, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dweibull, double)
 MAKE_RECYCLING_RULE_CLASS3_1scalar(dt_nonstandard, double)
@@ -1404,6 +1405,7 @@ MAKE_RECYCLING_RULE_CLASS3_2scalar(pgamma, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(pinvgamma, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(pdexp, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(plnorm, double)
+MAKE_RECYCLING_RULE_CLASS3_2scalar(plogis, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(punif, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(pweibull, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(pt_nonstandard, double)
@@ -1421,6 +1423,7 @@ MAKE_RECYCLING_RULE_CLASS3_2scalar(qgamma, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qinvgamma, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qdexp, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qlnorm, double)
+MAKE_RECYCLING_RULE_CLASS3_2scalar(qlogis, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qunif, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qweibull, double)
 MAKE_RECYCLING_RULE_CLASS3_2scalar(qt_nonstandard, double)
@@ -1438,6 +1441,7 @@ MAKE_RECYCLING_RULE_CLASS_r2(rgamma, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rinvgamma, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rdexp, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rlnorm, double)
+MAKE_RECYCLING_RULE_CLASS_r2(rlogis, double)
 MAKE_RECYCLING_RULE_CLASS_r2(runif, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rweibull, double)
 MAKE_RECYCLING_RULE_CLASS_r2(rt_nonstandard, double)
